@@ -9,6 +9,7 @@ from typing import Any
 from .description import BaseSensorDescription, SensorDescription
 from .device import DeviceKey
 from .device_class import DeviceClass
+from .units import Units
 from .value import SensorValue
 
 
@@ -97,10 +98,12 @@ class SensorData:
 
     def set_device_name(self, name: str, device_id: str | None = None) -> None:
         """Set the device name."""
+        self._device_id_to_name[device_id] = name
         self._get_device_info(device_id).name = name
 
     def set_device_type(self, device_type: str, device_id: str | None = None) -> None:
         """Set the device type."""
+        self._device_id_to_type[device_id] = device_type
         self._get_device_info(device_id).model = device_type
 
     @abstractmethod
@@ -159,7 +162,7 @@ class SensorData:
     def update_sensor(
         self,
         key: str,
-        native_unit_of_measurement: str | None,
+        native_unit_of_measurement: Units | None,
         native_value: None | str | int | float | date | datetime | Decimal,
         device_class: DeviceClass | None = None,
         name: str | None = None,
